@@ -277,7 +277,7 @@ main (int argc, char *argv[])
         struct sigaction              sa;
         GString                      *src_dir;
 	gchar                        *syslog_ident;
-	gchar                        *debug_output_env;
+	const gchar                  *debug_output_env;
 
         /*
          *    Become process group leader, detach from controlling
@@ -322,6 +322,8 @@ main (int argc, char *argv[])
 	debug_output_env = g_getenv ("BONOBO_ACTIVATION_DEBUG_OUTPUT");
 	if (debug_output_env && debug_output_env[0] != '\0')
 		output_debug = TRUE;
+        if (server_reg)
+                output_debug = TRUE;
 #endif
 
         dev_null_fd = redirect_output (ior_fd);
@@ -399,6 +401,11 @@ main (int argc, char *argv[])
 
         dump_ior (orb, dev_null_fd, ev);
 
+	od_finished_internal_registration (); 
+
+        if (getenv ("BONOBO_ACTIVATION_DEBUG") == NULL)
+                chdir ("/");
+
 	g_main_loop_run (main_loop);
 
         nameserver_destroy (root_poa, naming_service, ev);
